import {Module} from "@nestjs/common";
import {ConfigModule} from "@nestjs/config";
import {TypeOrmModule} from "@nestjs/typeorm";
import {AppController} from "./app.controller";
import {AppService} from "./app.service";
import {UsersRepository} from "./modules/users/user.repository";
import {UsersModule} from "./modules/users/users.module";
import {UsersService} from "./modules/users/users.service";
import {AuthModule} from "./modules/auth/auth.module";
import {JwtModule} from "@nestjs/jwt";
import {EmailNotifierModule} from "./modules/email-notifier/email-notifier.module";
import JwtConfigService from "./core/jwt/jwt-config.service";
import {MailerModule} from "@nestjs-modules/mailer";
import {HandlebarsAdapter} from "@nestjs-modules/mailer/dist/adapters/handlebars.adapter";
import {ServeStaticModule} from "@nestjs/serve-static";
import {join} from "path";
import {FileUploadsModule} from "./modules/file-uploads/file-uploads.module";
import {SendEmailModule} from "./modules/send-email/send-email.module";
import {SendEmailService} from "./modules/send-email/send-email.service";
import {SendEmailRepository} from "./modules/send-email/send-email-repository";
import {EmailNotifierRepository} from "./modules/email-notifier/email-notifier-repository";
import {FileUploadsService} from "./modules/file-uploads/file-uploads.service";
import {MailSenderModule} from "./modules/mail-sender/mail-sender.module";
import {SpacesModule} from "./modules/SpacesModule/spaces.module";
import {DoSpacesService} from "./modules/SpacesModule/SpacesService/doSpacesService";
import {DoSpacesServicerovider} from "./modules/SpacesModule/SpacesService";
import {CkeditorFileModule} from "./modules/ckeditor-file/ckeditor-file.module";
import {AboutUsPageCmsModule} from "./modules/CMS/about-us-page-cms/about-us-page-cms.module";
import {ContactUsPageCmsModule} from "./modules/CMS/contact-us-page-cms/contact-us-page-cms.module";
import {PrivacyPolicyCmsModule} from "./modules/CMS/privacy-policy-cms/privacy-policy-cms.module";
import {FAQPageCmsModule} from "./modules/CMS/faq-page-cms/faq-page-cms.module";
import {SecurityPageCmsModule} from "./modules/CMS/security-page-cms/security-page-cms.module";
import {SchedulePageCmsModule} from "./modules/CMS/schedule-page-cms/schedule-page-cms.module";
import {CareerPageCmsModule} from "./modules/CMS/career-page-cms/career-page-cms.module";
import {CareerDetailsPageCmsModule} from "./modules/CMS/career-details-page-cms/career-details-page-cms.module";
import {TermsPageCmsModule} from "./modules/CMS/terms-page-cms/terms-page-cms.module";
import {PressKitPageCmsModule} from "./modules/CMS/press-kit-page-cms/press-kit-page-cms.module";
import {PartnerPageCmsModule} from "./modules/CMS/partner-page-cms/partner-page-cms.module";
import {HeaderFooterCmsModule} from "./modules/CMS/header-footer-cms/header-footer-cms.module";
import {AboutPageContentModule} from "./modules/CRUD/about-page-content/about-page-content.module";
import {LeadersContentModule} from "./modules/CRUD/leaders-content/leaders-content.module";
import {ContactModelModule} from "./modules/CRUD/contact-model/contact-model.module";
import {FaqContentModule} from "./modules/CRUD/faq-content/faq-content.module";
import {SubscriptionModelModule} from "./modules/CRUD/subscription-model/subscription-model.module";
import {ScheduleModelModule} from "./modules/CRUD/schedule-model/schedule-model.module";
import {CareerModelModule} from "./modules/CRUD/career-model/career-model.module";
import {OfficeContentModule} from "./modules/CRUD/office-content/office-content.module";
import {CareerApplicationModelModule} from "./modules/CRUD/career-application-model/career-application-model.module";
import {PressLinkContentModule} from "./modules/CRUD/press-link-content/press-link-content.module";
import {PressCoverageContentModule} from "./modules/CRUD/press-coverage-content/press-coverage-content.module";
import {AccelerateContentModule} from "./modules/CRUD/accelerate-content/accelerate-content.module";
import {PremiumPartnersContentModule} from "./modules/CRUD/premium-partners-content/premium-partners-content.module";
import {SocialLinkModule} from "./modules/CRUD/social-link/social-link.module";
import {CareerTeamModule} from "./modules/CRUD/career-team/career-team.module";
import {CareerLocationModule} from "./modules/CRUD/career-location/career-location.module";
import {PressAboutContentCmsModule} from "./modules/CMS/press-about-content-cms/press-about-content-cms.module";
import {SiteFrontendModule} from "./modules/site-frontend/site-frontend.module";
import {DesignationModule} from "./modules/CRUD/designation/designation.module";
import {OrganizationSizeModule} from "./modules/CRUD/organization-size/organization-size.module";
import {ScheduleRoleModule} from "./modules/CRUD/schedule-role/schedule-role.module";
import {
    ScheduleTransactionLimitModule
} from "./modules/CRUD/schedule-transaction-limit/schedule-transaction-limit.module";
import {ScheduleIndustryModule} from "./modules/CRUD/schedule-industry/schedule-industry.module";
import {HomePageHeroSectionModule} from "./modules/CRUD/home-page-hero-section/home-page-hero-section.module";
import {HomePageBrandSectionModule} from "./modules/CRUD/home-page-brand-section/home-page-brand-section.module";
import {
    BenefitsAndAdvantageSectionModule
} from "./modules/CRUD/benefits-and-advantage-section/benefits-and-advantage-section.module";
import {
    BenefitsAndAdvantageSectionCmsModule
} from "./modules/CMS/benefits-and-advantage-section-cms/benefits-and-advantage-section-cms.module";
import {HomePageHeroSectionCmsModule} from "./modules/CMS/home-page-hero-section-cms/home-page-hero-section-cms.module";
import {SitePageTitleCmsModule} from "./modules/CMS/site-page-title-cms/site-page-title-cms.module";
import {ImproveSectionCmsModule} from "./modules/CMS/improve-section-cms/improve-section-cms.module";
import {SitePageMetaCmsModule} from "./modules/CMS/site-page-meta-cms/site-page-meta-cms.module";
import {HowItWorksSectionCmsModule} from "./modules/CMS/how-it-works-section-cms/how-it-works-section-cms.module";
import {HowItWorksSectionModule} from "./modules/CRUD/how-it-works-section/how-it-works-section.module";
import {NewsletterCmsModule} from "./modules/CMS/newsletter-cms/newsletter-cms.module";
import {CustomerReviewsCmsModule} from "./modules/CMS/customer-reviews-cms/customer-reviews-cms.module";
import {CustomerReviewsModule} from "./modules/CRUD/customer-reviews/customer-reviews.module";
import {EasyPaymentSectionCmsModule} from "./modules/CMS/easy-payment-section-cms/easy-payment-section-cms.module";
import {
    MarketYourBusinessSectionCmsModule
} from "./modules/CMS/market-your-business-section-cms/market-your-business-section-cms.module";
import {PaymentPackageModule} from "./modules/CRUD/payment-package/payment-package.module";
import {ApplicationsIntegrationModule} from "./modules/CRUD/applications-integration/applications-integration.module";
import {
    ApplicationsIntegrationCmsModule
} from "./modules/CMS/applications-integration-cms/applications-integration-cms.module";
import {WhatsNextSectionCmsModule} from "./modules/CMS/whats-next-section-cms/whats-next-section-cms.module";
import {SignupCmsModule} from "./modules/CMS/signup-cms/signup-cms.module";
import {SigninCmsModule} from "./modules/CMS/signin-cms/signin-cms.module";
import {AuthCommonDataModule} from "./modules/CRUD/auth-common-data/auth-common-data.module";
import {MessageModule} from './modules/message/message.module';
import {TransactionModule} from "./modules/transaction/transaction.module";
import {TransactionNotesModule} from "./modules/transaction-notes/transaction-notes.module";
import {PartyModule} from "./modules/party/party.module";
import {InvitesModule} from "./modules/invites/invites.module";
import { EventScheduleModule } from "./modules/event-schedule/event-schedule.module";
import { NotificationModule } from './modules/notification/notification.module';
import { TransactionAddressDetailsModule } from "./modules/transaction-address-details/transaction-address-details.module";
import { TransactionTimelineDetailsModule } from "./modules/transaction-timeline-details/transaction-timeline-details.module";
import { TransactionDocumentsModule } from "./modules/transaction-documents/transaction-documents.module";
import { LogsModule } from "./modules/transaction-logs/logs.module";

@Module({
    imports: [
        ServeStaticModule.forRoot({
            rootPath: join(__dirname, "..", "uploads")
        }),
        ConfigModule.forRoot({isGlobal: true}),
        TypeOrmModule.forRoot({
            type: "mysql",
            host: process.env.HOST,
            port: parseInt(process.env.PORT),
            username: process.env.USERNAME,
            // username: "root",
            password: process.env.PASSWORD,
            database: process.env.DATABASE,
            autoLoadEntities: true,
            synchronize: true,
            dropSchema: false
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([SendEmailRepository]),
        TypeOrmModule.forFeature([EmailNotifierRepository]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MailerModule.forRoot({
            transport: {
                host: process.env.EMAIL_HOST,
                port: parseInt(process.env.EMAIL_PORT),
                secure: true,
                auth: {
                    user: process.env.EMAIL_USER,
                    pass: process.env.EMAIL_PASS
                }
            },
            defaults: {
                from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`
            },
            template: {
                dir: __dirname + "/templates/**/*",
                adapter: new HandlebarsAdapter(),
                options: {
                    strict: true
                }
            }
        }),
        UsersModule,
        AuthModule,
        EmailNotifierModule,
        FileUploadsModule,
        SendEmailModule,
        MailSenderModule,
        SpacesModule,
        CkeditorFileModule,
        AboutUsPageCmsModule,
        ContactUsPageCmsModule,
        PrivacyPolicyCmsModule,
        FAQPageCmsModule,
        SecurityPageCmsModule,
        SchedulePageCmsModule,
        CareerPageCmsModule,
        CareerDetailsPageCmsModule,
        TermsPageCmsModule,
        PressKitPageCmsModule,
        PartnerPageCmsModule,
        HeaderFooterCmsModule,
        AboutPageContentModule,
        LeadersContentModule,
        ContactModelModule,
        FaqContentModule,
        SubscriptionModelModule,
        ScheduleModelModule,
        CareerModelModule,
        OfficeContentModule,
        CareerApplicationModelModule,
        PressLinkContentModule,
        PressCoverageContentModule,
        AccelerateContentModule,
        PremiumPartnersContentModule,
        SocialLinkModule,
        CareerTeamModule,
        CareerLocationModule,
        PressAboutContentCmsModule,
        SiteFrontendModule,
        DesignationModule,
        OrganizationSizeModule,
        ScheduleRoleModule,
        ScheduleTransactionLimitModule,
        ScheduleIndustryModule,
        HomePageHeroSectionModule,
        HomePageBrandSectionModule,
        BenefitsAndAdvantageSectionModule,
        BenefitsAndAdvantageSectionCmsModule,
        MarketYourBusinessSectionCmsModule,
        HomePageHeroSectionCmsModule,
        SitePageTitleCmsModule,
        ImproveSectionCmsModule,
        SitePageMetaCmsModule,
        HowItWorksSectionCmsModule,
        HowItWorksSectionModule,
        NewsletterCmsModule,
        CustomerReviewsCmsModule,
        CustomerReviewsModule,
        EasyPaymentSectionCmsModule,
        PaymentPackageModule,
        ApplicationsIntegrationModule,
        ApplicationsIntegrationCmsModule,
        WhatsNextSectionCmsModule,
        SignupCmsModule,
        SigninCmsModule,
        AuthCommonDataModule,
        TransactionModule,
        TransactionNotesModule,
        MessageModule,
        // TransactionModule,
        PartyModule,
        InvitesModule,
        EventScheduleModule,
        NotificationModule,
        TransactionAddressDetailsModule,
        TransactionTimelineDetailsModule,
        TransactionDocumentsModule,
        LogsModule
    ],
    controllers: [AppController],
    providers: [
        AppService,
        UsersService,
        SendEmailService,
        FileUploadsService,
        DoSpacesService,
        DoSpacesServicerovider
    ]
})
export class AppModule {
}
