import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {CareerPageCmsService} from "./career-page-cms.service";
import {UpdateCareerPageCmsDto} from "./dto/update-career-page-cms.dto";

@Controller({path: "career-page-cms", version: Constants.API_VERSION_1})

export class CareerPageCmsController {
    constructor(private readonly service: CareerPageCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "backgroundImage", maxCount: 1},
            {name: "mobileBackgroundImage", maxCount: 1}
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateCareerPageCmsDto,
        @UploadedFiles() files: {
            backgroundImage: UploadedMulterFileI,
            mobileBackgroundImage: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
