import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {DoSpacesService} from "../../SpacesModule/SpacesService/doSpacesService";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";
import {MarketYourBusinessSectionCmsRepository} from './market-your-business-section-cms.repository';
import {UpdateMarketYourBusinessSectionCmsDto} from './dto/update-market-your-business-section-cms.dto';
import {MarketYourBusinessSectionCmsEntity} from './entity/market-your-business-section-cms.entity';

@Injectable()
export class MarketYourBusinessSectionCmsService {
    constructor(
        @InjectRepository(MarketYourBusinessSectionCmsRepository)
        private readonly repository: MarketYourBusinessSectionCmsRepository,
        private readonly doSpacesService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateMarketYourBusinessSectionCmsDto,
        files: {
            image?: UploadedMulterFileI
        }
    ): Promise<MarketYourBusinessSectionCmsEntity | Error> {
        if (files && files.image) {
            const url = await this.doSpacesService.uploadFile(files.image[0], "MarketYourBusinessSectionCms/");
            dto.image = url.toString();
        }
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(id, dto);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<MarketYourBusinessSectionCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }
}
