import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {PressKitPageCmsService} from "./press-kit-page-cms.service";
import {UpdatePressKitPageCmsDto} from "./dto/update-press-kit-page-cms.dto";

@Controller({path: "press-kit-page-cms", version: Constants.API_VERSION_1})

export class PressKitPageCmsController {
    constructor(private readonly service: PressKitPageCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "aboutIcon", maxCount: 1},
            {name: "linkIcon", maxCount: 1},
            {name: "pressCoverageIcon", maxCount: 1},
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdatePressKitPageCmsDto,
        @UploadedFiles() files: {
            aboutIcon: UploadedMulterFileI,
            linkIcon: UploadedMulterFileI,
            pressCoverageIcon: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
