import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {PressKitPageCmsRepository} from "./press-kit-page-cms.repository";
import {UpdatePressKitPageCmsDto} from "./dto/update-press-kit-page-cms.dto";
import {PressKitPageCmsEntity} from "./entities/press-kit-page-cms.entity";

@Injectable()
export class PressKitPageCmsService {
    constructor(
        @InjectRepository(PressKitPageCmsRepository)
        private readonly repository: PressKitPageCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdatePressKitPageCmsDto,
        files: {
            aboutIcon: UploadedMulterFileI,
            linkIcon: UploadedMulterFileI,
            pressCoverageIcon: UploadedMulterFileI
        }
    ): Promise<PressKitPageCmsEntity | Error> {
        if (files && files.aboutIcon) {
            const aboutIcon: any = await this.doSpaceService.uploadFile(files.aboutIcon[0], "PressKitPageCms/");
            dto.aboutIcon = aboutIcon;
        }

        if (files && files.linkIcon) {
            const linkIcon: any = await this.doSpaceService.uploadFile(files.linkIcon[0], "PressKitPageCms/");
            dto.linkIcon = linkIcon;
        }

        if (files && files.pressCoverageIcon) {
            const pressCoverageIcon: any = await this.doSpaceService.uploadFile(files.pressCoverageIcon[0], "PressKitPageCms/");
            dto.pressCoverageIcon = pressCoverageIcon;
        }

        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<PressKitPageCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}