import {
    Body,
    Controller,
    Get,
    HttpCode,
    HttpStatus,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from "@nestjs/common";
import {AdminAuthGuard} from "src/core/guards/admin-auth.guard";
import {Constants} from "src/utils/constants";
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";
import {SchedulePageCmsService} from "./schedule-page-cms.service";
import {UpdateSchedulePageCmsDto} from "./dto/update-schedule-page-cms.dto";

@Controller({path: "schedule-page-cms", version: Constants.API_VERSION_1})

export class SchedulePageCmsController {
    constructor(private readonly service: SchedulePageCmsService) {
    }

    @Post()
    @HttpCode(HttpStatus.OK)
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
        [
            {name: "icon", maxCount: 1}
        ]
    ))
    updateOrCreateData(
        @Body() dto: UpdateSchedulePageCmsDto,
        @UploadedFiles() files: {
            icon: UploadedMulterFileI
        }
    ) {
        return this.service.updateOrCreateData(dto, files);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }
}
