import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {FileUploadsService} from 'src/modules/file-uploads/file-uploads.service';
import {CareerApplicationModelRepository} from './career-application-model.repository';
import {CreateCareerApplicationModelDto} from './dto/create-career-application-model.dto';
import {CareerApplicationModelEntity} from './entity/career-application-model.entity';
import {UpdateCareerApplicationModelDto} from './dto/update-career-application-model.dto';
import {DoSpacesService} from 'src/modules/SpacesModule/SpacesService/doSpacesService';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';

@Injectable()
export class CareerApplicationModelService {
    constructor(
        @InjectRepository(CareerApplicationModelRepository)
        private readonly repository: CareerApplicationModelRepository,
        private readonly fileService: FileUploadsService,
        private readonly doSpacesService: DoSpacesService
    ) {
    }

    async create(
        dto: CreateCareerApplicationModelDto,
        files: {
            resume?: UploadedMulterFileI,
            coverLetter?: UploadedMulterFileI,
        }
    ): Promise<CareerApplicationModelEntity | Error> {
        if (files && files.resume) {
            const url = await this.doSpacesService.uploadFile(files.resume[0], "CareerApplicationModel/");
            dto.resume = url.toString();
        }
        if (files && files.coverLetter) {
            const url = await this.doSpacesService.uploadFile(files.coverLetter[0], "CareerApplicationModel/");
            dto.coverLetter = url.toString();
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
    }

    async update(
        id: string,
        dto: UpdateCareerApplicationModelDto,
        files: {
            resume?: UploadedMulterFileI,
            coverLetter?: UploadedMulterFileI,
        }
    ): Promise<CareerApplicationModelEntity | Error> {
        const res: any = await this.repository.findOneEntity(id);
        if (!res) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        if (files && files.resume) {
            const url = await this.doSpacesService.uploadFile(files.resume[0], "CareerApplicationModel/");
            dto.resume = url.toString();
        }
        if (files && files.coverLetter) {
            const url = await this.doSpacesService.uploadFile(files.coverLetter[0], "CareerApplicationModel/");
            dto.coverLetter = url.toString();
        }
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
    }

    async findAll(): Promise<CareerApplicationModelEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<CareerApplicationModelEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data deleted successfully");
    }
}
