import {
    Body,
    Controller,
    Delete,
    Get,
    Param,
    Patch,
    Post,
    UploadedFiles,
    UseGuards,
    UseInterceptors
} from '@nestjs/common';
import {AdminAuthGuard} from 'src/core/guards/admin-auth.guard';
import {Constants} from 'src/utils/constants';
import {CustomerReviewsService} from './customer-reviews.service';
import {CreateCustomerReviewsDto} from './dto/create-customer-reviews.dto';
import {UpdateCustomerReviewsDto} from './dto/update-customer-reviews.dto';
import {FileFieldsInterceptor} from "@nestjs/platform-express";
import {UploadedMulterFileI} from "../../SpacesModule/SpacesService";

@Controller({path: 'customer-reviews', version: Constants.API_VERSION_1})
export class CustomerReviewsController {
    constructor(private readonly service: CustomerReviewsService) {
    }

    @Post()
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'userPhoto', maxCount: 1},
        {name: 'icon', maxCount: 1}
    ]))
    create(
        @Body() dto: CreateCustomerReviewsDto,
        @UploadedFiles() files: {
            userPhoto?: UploadedMulterFileI,
            icon?: UploadedMulterFileI,
        }
    ) {
        return this.service.create(dto, files);
    }

    @Get()
    @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(':id')
    @UseGuards(AdminAuthGuard)
    findOne(@Param('id') id: string) {
        return this.service.findOne(id);
    }

    @Patch(':id')
    @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor([
        {name: 'userPhoto', maxCount: 1},
        {name: 'icon', maxCount: 1}
    ]))
    update(
        @Param('id') id: string,
        @Body() dto: UpdateCustomerReviewsDto,
        @UploadedFiles() files: {
            userPhoto?: UploadedMulterFileI,
            icon?: UploadedMulterFileI,
        }) {
        return this.service.update(id, dto, files);
    }

    @Delete(':id')
    @UseGuards(AdminAuthGuard)
    async remove(@Param('id') id: string) {
        return await this.service.remove(id);
    }
}
