import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {OfficeContentRepository} from './office-content.repository';
import {CreateOfficeContentDto} from './dto/create-office-content.dto';
import {UpdateOfficeContentDto} from './dto/update-office-content.dto';
import {OfficeContentEntity} from './entity/office-content.entity';

@Injectable()
export class OfficeContentService {
    constructor(
        @InjectRepository(OfficeContentRepository)
        private readonly repository: OfficeContentRepository
    ) {
    }

    async create(dto: CreateOfficeContentDto): Promise<OfficeContentEntity | Error> {
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Data Created Successfully", "data", data);
    }

    async findAll(): Promise<OfficeContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async update(id: string, dto: UpdateOfficeContentDto): Promise<OfficeContentEntity | Error> {
        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
    }

    async findOne(id: string): Promise<OfficeContentEntity[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Data Deleted Successfully");
    }
}
