import {EntityRepository, getConnection, Repository} from "typeorm";
import {CreateSocialLinkDto} from "./dto/create-social-link.dto";
import {UpdateSocialLinkDto} from "./dto/update-social-link.dto";
import {SocialLinkEntity} from "./entity/social-link.entity";

@EntityRepository(SocialLinkEntity)
export class SocialLinkRepository extends Repository<SocialLinkEntity> {
    async createEntity(dto: CreateSocialLinkDto): Promise<SocialLinkEntity | Error> {
        try {
            const {
                title,
                link,
                icon
            } = dto;
            const entity = this.create({
                title,
                link,
                icon
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<SocialLinkEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateSocialLinkDto): Promise<SocialLinkEntity | Error> {
        try {
            await this.update(id, {
                title: dto.title,
                link: dto.link,
                icon: dto.icon
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<SocialLinkEntity[] | Error> {
        try {
            return await this.find({
                where: {...query, isDeleted: false}
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(SocialLinkEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}