import {HttpException, HttpStatus, Injectable} from '@nestjs/common';
import {InjectRepository} from '@nestjs/typeorm';
import {Constants} from 'src/utils/constants';
import {ResponseUtils} from 'src/utils/response.utils';
import {CkeditorFileRepository} from './ckeditor-file.repository';
import {CreateCkeditorFileDto} from './dto/create-ckeditor-file.dto';
import {UpdateCkeditorFileDto} from './dto/update-ckeditor-file.dto';
import {CkeditorFile} from './entities/ckeditor-file.entity';
import {UploadedMulterFileI} from 'src/modules/SpacesModule/SpacesService';
import {DoSpacesService} from 'src/modules/SpacesModule/SpacesService/doSpacesService';

@Injectable()
export class CkeditorFileService {
    constructor(
        @InjectRepository(CkeditorFileRepository)
        private readonly repository: CkeditorFileRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(
        dto: CreateCkeditorFileDto,
        files: {
            upload: UploadedMulterFileI,
        }): Promise<any | Error> {
        // process image one
        if (files && files.upload) {
            const image: any = await this.doSpaceService.uploadFile(files.upload[0], 'CkeditorFile/');
            dto.upload = image;
        }

        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
                Constants.CREATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }

        var url = data['url'];
        var filename = url.substring(url.lastIndexOf('/') + 1);

        console.log('FileName =', filename);

        let dataFile = {
            'uploaded': 1,
            'fileName': filename,
            'url': url
        };

        return dataFile;
    }

    async findAll(): Promise<CkeditorFile[] | Error> {
        const data = await this.repository.findByFilterQuery({});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery fetched successfully", "data", data);
    }

    async update(
        id: string,
        dto: UpdateCkeditorFileDto,
        files: {
            image: UploadedMulterFileI,
        }
    ): Promise<CkeditorFile | Error> {
        const CkeditorFile: any = await this.repository.findOneEntity(id);
        if (!CkeditorFile) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }

        // process image one
        if (files && files.image) {
            const image: any = await this.doSpaceService.uploadFile(files.image[0], 'CkeditorFile/');
            dto.upload = image;
        }

        const data = await this.repository.updateEntity(id, dto);
        if (!data) {
            throw new HttpException(
                Constants.UPDATE_FAILED,
                HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery updated successfully", "data", data);
    }

    async findOne(id: string): Promise<CkeditorFile[] | Error> {
        const data = await this.repository.findByFilterQuery({id: id});
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product image gallery fetched successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product image gallery deleted successfully");
    }
}
