import { EntityRepository, getConnection, Repository } from "typeorm";
import { EventScheduleGuestEntity } from "./entities/event-schedule-guest.entity";
import { CreateEventScheduleDto } from "./dto/createEventSchedule.dto";

@EntityRepository(EventScheduleGuestEntity)
export class EventScheduleGuestRepository extends Repository<EventScheduleGuestEntity> {
    async createEntity(createGuestObj: any): Promise<any | Error> {
        try {
            const entity = this.create(createGuestObj);
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<EventScheduleGuestEntity[] | Error> {
        try {
            return await this.find({
                where: { ...query, isDeleted: false }
            });
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<EventScheduleGuestEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findScheduleOfUser(id: string, page: number, limit: number): Promise<{ data: EventScheduleGuestEntity[], nextPage: number | null, previousPage: number | null, totalCount: number }> {
        const skip = (page - 1) * limit;
        const [data, totalCount] = await this.createQueryBuilder('event_schedule')
            .where('event_schedule.invitedUserId = :id', { id })
            .orWhere('event_schedule.invitedBy = :id', { id })
            .andWhere('event_schedule.isDeleted = 0')
            .orderBy('event_schedule.startTime', 'ASC')
            .skip(skip)
            .take(limit)
            .getManyAndCount();

        const totalPages = Math.ceil(totalCount / limit);
        const nextPage = page < totalPages ? page + 1 : null;
        const previousPage = page > 1 ? page - 1 : null;

        return {
            data,
            previousPage,
            nextPage,
            totalCount,
        };
    }

    async updateEntity(id: string, dto: any): Promise<EventScheduleGuestEntity | Error> {
        try {
            await this.update(id, { ...dto });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(EventScheduleGuestEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async deleteByScheduleId(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(EventScheduleGuestEntity)
                .set({ isDeleted: true })
                .where("eventScheduleId = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}