import {EntityRepository, Repository} from "typeorm";
import {SingleMessageDto} from "./dto/single-message.dto";
import {Message} from "./entities/message.entity";
import {OneToOneMessageDto} from "./dto/one-to-one-message.dto";
import {GroupMessageDto} from "./dto/group-message.dto";
import {AllGroupMessageDto} from "./dto/all-group-message.dto";

@EntityRepository(Message)
export class MessageRepository extends Repository<Message> {
    async createEntity(dto: SingleMessageDto): Promise<Message | Error> {
        try {
            const entity = this.create({...dto});
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findAllOneToOne(dto: OneToOneMessageDto): Promise<Message[] | Error> {
        const senderToReceive = {senderId: dto.senderId, receiverId: dto.receiverId};
        const receiverToSender = {receiverId: dto.senderId, senderId: dto.receiverId}
        try {
            return await this.find({where: [senderToReceive, receiverToSender], order: {createdAt: 'ASC'}})
        } catch (error) {
            throw error;
        }
    }

    async createEntityForGroup(dto: GroupMessageDto) {
        try {
            const entity = this.create({...dto});
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findAllGroupMessage(dto: AllGroupMessageDto): Promise<Message[] | Error> {
        try {
            return await this.find({where: {transactionId: dto.transactionId}, order: {createdAt: 'ASC'}})
        } catch (error) {
            throw error;
        }
    }
}