import { Injectable } from '@nestjs/common';
import { CreateNotificationDto } from './dto/create-notification.dto';
import { NotificationRepository } from "./notification.repository";
import { InjectRepository } from "@nestjs/typeorm";
import { UpdateNotificationDto } from "./dto/update-notification.dto";
import { ResponseUtils } from "src/utils/response.utils";

@Injectable()
export class NotificationService {  
  constructor(@InjectRepository(NotificationRepository) private readonly repository: NotificationRepository) { }

  async create(dto: CreateNotificationDto) {
    return await this.repository.createEntity(dto);
  }

  async findSeenNotificationsByUserId(userId: string, seen: string) {
    const data = await this.repository.findByFilterQuery({ userId, seen: seen == 'true' ? 1 : 0 });
    return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
  }

  async findNotificationsByUserId(userId: string) {
    const data = await this.repository.findByUserId(userId);
    return ResponseUtils.successResponseHandler(200, "Data Fetched Successfully", "data", data);
  }

  async update(id: string, dto: UpdateNotificationDto) {
    const { userId, ...restDto } = dto;
    await this.repository.updateEntity(id, restDto);
    const data = await this.repository.findByUserId(userId);
    return ResponseUtils.successResponseHandler(200, "Data Updated Successfully", "data", data);
  }
}
