import { Controller, Get, Param, Req } from '@nestjs/common';
import { Constants } from "src/utils/constants";
import { Body, Patch, Query, UseGuards } from "@nestjs/common/decorators";
import { SiteFrontendService } from "./site-frontend.service";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { AuthGuard } from "src/core/guards/auth.guard";

@Controller({
    path: "site",
    version: Constants.API_VERSION_1
})
export class SiteFrontendController {
    constructor(private readonly service: SiteFrontendService) {
    }

    @Get("/faq-page")
    getFaqPageData() {
        return this.service.getFaqPageData();
    }

    @Get('/about-page')
    getAboutPageData() {
        return this.service.getAboutPageData();
    }

    @Get('/press')
    getPressData() {
        return this.service.getPressData();
    }

    @Get('/career')
    getCareerPageData() {
        return this.service.getCareerPageData();
    }

    @Get('/contact-page')
    getContactPageData() {
        return this.service.getContactPageData();
    }

    @Get('/partner-page')
    getPartnerPageData() {
        return this.service.getPartnerPageData();
    }

    @Get('/common-cms')
    getCommonCMSData() {
        return this.service.getCommonCMSData();
    }

    @Get("/career-list")
    getCareerListData(
        @Query("keyword") keyword?: any,
        @Query("teamName") teamName?: any,
        @Query("location") location?: any
    ) {
        return this.service.getCareerListData(keyword, teamName, location);
    }

    @Get("/career-details/:id")
    getCareerDetailsData(
        @Param("id") id: string
    ) {
        return this.service.getCareerDetailsData(id);
    }

    @Get('/schedule')
    getScheduleData() {
        return this.service.getScheduleData();
    }

    @Get('/home')
    getHomePageData() {
        return this.service.getHomePageData();
    }

    @Get("/admin-dashboard")
    @UseGuards(AdminAuthGuard)
    getDashboardData() {
        return this.service.getDashboardData();
    }

    @Get("/transaction")
    @UseGuards(AuthGuard)
    getSiteTransaction(@Req() request: any) {
        return this.service.getSiteTransaction(request.user);
    }

    @Get('/transaction-details/:id')
    @UseGuards(AuthGuard)
    findTransactionDetails(@Param('id') id: string) {
        return this.service.findTransactionDetailsById(id);
    }

    @Get('/user-schedule')
    @UseGuards(AuthGuard)
    findUserSchedule(
        @Req() request: any,
        @Query('page') pageParam: string,
        @Query('limit') limitParam: string
    ) {
        const page = parseInt(pageParam, 10) || 1;
        const limit = parseInt(limitParam, 10) || 10;
        return this.service.findUserSchedule(request.user.id, page, limit);
    }

    @Get('/user-profile')
    @UseGuards(AuthGuard)
    getUserProfile(@Req() request: any) {
        return this.service.getUserProfile(request.user.id);
    }

    @Get('/user-invites')
    @UseGuards(AuthGuard)
    getUserInvites(@Req() request: any) {
        return this.service.getUserInvites(request.user.id);
    }

    @Patch('/change-transaction-owner/:id')
    @UseGuards(AuthGuard)
    changeTransactionOwner(@Req() request: any, @Param("id") transactionId: string, @Body() dto: any) {
        return this.service.changeTransactionOwner(request.user, transactionId, dto);
    }

    @Get('/user-payments')
    @UseGuards(AuthGuard)
    getPayments(@Req() request: any,
    @Query('page') pageParam: string,
    @Query('limit') limitParam: string,
    @Query('date') dateParam: string) {
        const page = parseInt(pageParam, 10) || 1;
        const limit = parseInt(limitParam, 10) || 10;
        return this.service.getUserPayments(request.user.id, page, limit, dateParam);
    }

}
