import { EntityRepository, getConnection, getManager, Repository } from "typeorm";
import { UpdateTransactionPaymentHistoryDto } from "./dto/update-transaction-payment-history.dto";
import { TransactionPaymentHistoryEntity } from "./entity/transaction-payment-history.entity";

@EntityRepository(TransactionPaymentHistoryEntity)
export class TransactionPaymentHistoryRepository extends Repository<TransactionPaymentHistoryEntity> {
    async createEntity(dto: any) {
        try {
            const entity = this.create(
                dto
            );
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<TransactionPaymentHistoryEntity | Error> {
        try {
            return this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateTransactionPaymentHistoryDto): Promise<TransactionPaymentHistoryEntity | Error> {
        try {
            await this.update(id, dto);
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<TransactionPaymentHistoryEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "ASC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async findLatestEntity(transactionId: string): Promise<TransactionPaymentHistoryEntity | Error> {
        try {
            return this.findOne({
                where: {
                    transactionId: transactionId
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(TransactionPaymentHistoryEntity)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            return updateResult.affected > 0;

        } catch (e) {
            return e;
        }
    }

    async getPaymentsOfUser(id: string, page: number, limit: number, date: string) {
        const offset = (page - 1) * limit;
        let countSql;
        if (!date) {
            countSql = `SELECT COUNT(*) AS total FROM transaction_payment_history WHERE userId = '${id}';`;
        } else {
            countSql = `SELECT COUNT(*) AS total FROM transaction_payment_history WHERE userId = '${id}'
            AND CAST(createdAt as date) = '${date}'
            ;`;
        }
        let dataSql = `SELECT paymentHis.id, paymentHis.paymentType, trans.streetAddress, 
        CONCAT(user.firstName, ' ', user.lastName) as recipient, paymentHis.amount, paymentHis.createdAt
        FROM transaction_payment_history paymentHis
        LEFT JOIN transaction trans ON paymentHis.transactionId = trans.id
        LEFT JOIN users user ON paymentHis.userId = user.id
        LEFT JOIN transaction_timeline_details timeline ON paymentHis.transactionTimelineId = timeline.id
        WHERE paymentHis.userId = '${id}'`;
        if (date) {
            dataSql = `${dataSql} AND CAST(paymentHis.createdAt as date) = '${date}'`;
        }
        dataSql = `${dataSql} ORDER BY paymentHis.createdAt DESC LIMIT ${limit} OFFSET ${offset};`;

        const entityManager = getManager();
        const [totalCountResult, data] = await Promise.all([
            entityManager.query(countSql),
            entityManager.query(dataSql),
        ]);

        const totalCount = totalCountResult[0].total;
        const totalPages = Math.ceil(totalCount / limit);
        const nextPage = page < totalPages ? page + 1 : null;
        const previousPage = page > 1 ? page - 1 : null;

        return {
            data,
            totalCount,
            totalPages,
            nextPage,
            previousPage,
        };
    }
}